import type { SvelteComponent } from "svelte";
declare type objString = {
    [key: string]: string;
};
interface MetadataRoute {
    metadata: true;
    defaultLoading?: SvelteComponent;
    defaultAuthComponent?: SvelteComponent;
}
interface LayoutRoute {
    layout: true | number;
    component: SvelteComponent;
}
interface DeprecatedLazyRoute {
    path: string;
    lazyLoad: {
        component: () => Promise<SvelteComponent>;
        loading?: SvelteComponent | string | false;
    };
}
interface LazyRoute {
    path: string;
    lazyLoad: true;
    component: () => Promise<SvelteComponent>;
    loading?: SvelteComponent | string | false;
}
interface StaticRoute {
    path: string;
    component: SvelteComponent | string;
}
interface ProtectedRouteBase {
    authenticator: () => boolean | Promise<boolean>;
    authComponent?: SvelteComponent | string | false;
    authRedirect?: string;
}
declare type ProtectedStaticRoute = StaticRoute & ProtectedRouteBase;
declare type DeprecatedProtectedLazyRoute = DeprecatedLazyRoute & ProtectedRouteBase;
declare type ProtectedLazyRoute = LazyRoute & ProtectedRouteBase;
declare type Route = Route3 | DeprecatedLazyRoute | DeprecatedProtectedLazyRoute;
declare type Route2 = StaticRoute | LazyRoute | ProtectedStaticRoute | ProtectedLazyRoute;
declare type Route3 = Route2 | MetadataRoute | LayoutRoute;
interface RouterStoreValue {
    pathname: string;
    params: objString;
    loadingStatus: "none" | "pending" | "error";
    authStatus: "none" | "pending" | "fail" | "error";
    component?: SvelteComponent;
    layout?: SvelteComponent;
    error?: Error;
    targetName?: string;
    currentRoute: Route2;
    routes: Route3[];
}
export declare const routerStore: {
    subscribe: (run: (value: RouterStoreValue) => void, invalidate?: ((value?: RouterStoreValue | undefined) => void) | undefined) => () => void;
    update(newValue: Partial<RouterStoreValue>): void;
    renderRoute(route: Route2, metadata?: MetadataRoute | undefined): Partial<RouterStoreValue>;
    render(value: RouterStoreValue, pathname: string): RouterStoreValue;
    redirect(pathname: string, replace?: boolean | undefined): void;
    setRoutes(routes: Route[], pathname: string): void;
};
export declare const isActive: import("svelte/store").Readable<(path: string) => boolean>;
/** LO stands for LoopOver */
export declare function LO(...args: string[][]): Generator<(string | undefined)[], void, unknown>;
export {};
